pub struct ClusterAgentSchedulingCustomization {
pub pod_disruption_budget: Option<ClusterAgentSchedulingCustomizationPodDisruptionBudget>,
pub priority_class: Option<ClusterAgentSchedulingCustomizationPriorityClass>,
}Fields
pod_disruption_budget: Option<ClusterAgentSchedulingCustomizationPodDisruptionBudget>priority_class: Option<ClusterAgentSchedulingCustomizationPriorityClass>Trait Implementations
Sourceimpl Clone for ClusterAgentSchedulingCustomization
impl Clone for ClusterAgentSchedulingCustomization
Sourcefn clone(&self) -> ClusterAgentSchedulingCustomization
fn clone(&self) -> ClusterAgentSchedulingCustomization
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for ClusterAgentSchedulingCustomization
impl Default for ClusterAgentSchedulingCustomization
Sourcefn default() -> ClusterAgentSchedulingCustomization
fn default() -> ClusterAgentSchedulingCustomization
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for ClusterAgentSchedulingCustomization
impl<'de> Deserialize<'de> for ClusterAgentSchedulingCustomization
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ClusterAgentSchedulingCustomization
impl JsonSchema for ClusterAgentSchedulingCustomization
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ClusterAgentSchedulingCustomization
impl PartialEq for ClusterAgentSchedulingCustomization
Sourcefn eq(&self, other: &ClusterAgentSchedulingCustomization) -> bool
fn eq(&self, other: &ClusterAgentSchedulingCustomization) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ClusterAgentSchedulingCustomization