pub struct ClusterAgentSchedulingCustomizationPriorityClass {
pub preemption_policy: Option<String>,
pub value: Option<i64>,
}Fields
preemption_policy: Option<String>PreemptionPolicy describes a policy for if/when to preempt a pod.
value: Option<i64>Trait Implementations
Sourceimpl Clone for ClusterAgentSchedulingCustomizationPriorityClass
impl Clone for ClusterAgentSchedulingCustomizationPriorityClass
Sourcefn clone(&self) -> ClusterAgentSchedulingCustomizationPriorityClass
fn clone(&self) -> ClusterAgentSchedulingCustomizationPriorityClass
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for ClusterAgentSchedulingCustomizationPriorityClass
impl Default for ClusterAgentSchedulingCustomizationPriorityClass
Sourcefn default() -> ClusterAgentSchedulingCustomizationPriorityClass
fn default() -> ClusterAgentSchedulingCustomizationPriorityClass
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for ClusterAgentSchedulingCustomizationPriorityClass
impl<'de> Deserialize<'de> for ClusterAgentSchedulingCustomizationPriorityClass
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ClusterAgentSchedulingCustomizationPriorityClass
impl JsonSchema for ClusterAgentSchedulingCustomizationPriorityClass
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ClusterAgentSchedulingCustomizationPriorityClass
impl PartialEq for ClusterAgentSchedulingCustomizationPriorityClass
Sourcefn eq(&self, other: &ClusterAgentSchedulingCustomizationPriorityClass) -> bool
fn eq(&self, other: &ClusterAgentSchedulingCustomizationPriorityClass) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ClusterAgentSchedulingCustomizationPriorityClass