ClusterStatus

Struct ClusterStatus 

pub struct ClusterStatus {
Show 28 fields pub active_schedule: Option<bool>, pub agent: Option<ClusterStatusAgent>, pub agent_affinity_hash: Option<String>, pub agent_config_changed: Option<bool>, pub agent_deployed_generation: Option<i64>, pub agent_env_vars_hash: Option<String>, pub agent_host_network: Option<bool>, pub agent_migrated: Option<bool>, pub agent_namespace_migrated: Option<bool>, pub agent_private_repo_url: Option<String>, pub agent_resources_hash: Option<String>, pub agent_scheduling_customization_hash: Option<String>, pub agent_tls_mode: Option<String>, pub agent_tolerations_hash: Option<String>, pub api_server_ca_hash: Option<String>, pub api_server_url: Option<String>, pub cattle_namespace_migrated: Option<bool>, pub conditions: Option<Vec<ClusterStatusConditions>>, pub desired_ready_git_repos: Option<i64>, pub desired_ready_helm_ops: Option<i64>, pub display: Option<ClusterStatusDisplay>, pub garbage_collection_interval: Option<String>, pub namespace: Option<String>, pub ready_git_repos: Option<i64>, pub ready_helm_ops: Option<i64>, pub resource_counts: Option<ClusterStatusResourceCounts>, pub scheduled: Option<bool>, pub summary: Option<ClusterStatusSummary>,
}

Fields

active_schedule: Option<bool>

ActiveSchedule specifies if the cluster is in schedule, which means BundleDeployments can be updated and deployed. If ActiveSchedule is set to false and Scheduled is set to true BundleDeployments are not updated nor deployed.

agent: Option<ClusterStatusAgent>

AgentStatus contains information about the agent.

agent_affinity_hash: Option<String>

AgentAffinityHash is a hash of the agent’s affinity configuration, used to detect changes.

agent_config_changed: Option<bool>

AgentConfigChanged is set to true if any of the agent configuration changed, like the API server URL or CA. Setting it to true will trigger a re-import of the cluster.

agent_deployed_generation: Option<i64>

AgentDeployedGeneration is the generation of the agent that is currently deployed.

agent_env_vars_hash: Option<String>

AgentEnvVarsHash is a hash of the agent’s env vars, used to detect changes.

agent_host_network: Option<bool>

AgentHostNetwork defines observed state of spec.hostNetwork setting that is currently used.

agent_migrated: Option<bool>

AgentMigrated is always set to true after importing a cluster. If false, it will trigger a migration. Old agents don’t have this in their status.

agent_namespace_migrated: Option<bool>

AgentNamespaceMigrated is always set to true after importing a cluster. If false, it will trigger a migration. Old Fleet agents don’t have this in their status.

agent_private_repo_url: Option<String>

AgentPrivateRepoURL is the private repo URL for the agent that is currently used.

agent_resources_hash: Option<String>

AgentResourcesHash is a hash of the agent’s resources configuration, used to detect changes.

agent_scheduling_customization_hash: Option<String>agent_tls_mode: Option<String>

AgentTLSMode supports two values: system-store and strict. If set to system-store, instructs the agent to trust CA bundles from the operating system’s store. If set to strict, then the agent shall only connect to a server which uses the exact CA configured when creating/updating the agent.

agent_tolerations_hash: Option<String>

AgentTolerationsHash is a hash of the agent’s tolerations configuration, used to detect changes.

api_server_ca_hash: Option<String>

APIServerCAHash is a hash of the upstream API server CA, used to detect changes.

api_server_url: Option<String>

APIServerURL is the currently used URL of the API server that the cluster uses to connect to upstream.

cattle_namespace_migrated: Option<bool>

CattleNamespaceMigrated is always set to true after importing a cluster. If false, it will trigger a migration. Old Fleet agents, don’t have this in their status.

conditions: Option<Vec<ClusterStatusConditions>>desired_ready_git_repos: Option<i64>

DesiredReadyGitRepos is the number of gitrepos for this cluster that are desired to be ready.

desired_ready_helm_ops: Option<i64>

DesiredReadyHelmOps is the number of helmop resources for this cluster that are desired to be ready.

display: Option<ClusterStatusDisplay>

Display contains the number of ready bundles, nodes and a summary state.

garbage_collection_interval: Option<String>

GarbageCollectionInterval determines how often agents clean up obsolete Helm releases.

namespace: Option<String>

Namespace is the cluster namespace, it contains the clusters service account as well as any bundledeployments. Example: “cluster-fleet-local-cluster-294db1acfa77-d9ccf852678f”

ready_git_repos: Option<i64>

ReadyGitRepos is the number of gitrepos for this cluster that are ready.

ready_helm_ops: Option<i64>

ReadyHelmOps is the number of helmop resources for this cluster that are ready.

resource_counts: Option<ClusterStatusResourceCounts>

ResourceCounts is an aggregate over the ResourceCounts.

scheduled: Option<bool>

Scheduled specifies if the cluster has been added to any Schedule. When set to true ActiveSchedule is taken into account to check if the deployment can be deployed.

summary: Option<ClusterStatusSummary>

Summary is a summary of the bundledeployments.